Crate nitro_mods

Crate nitro_mods 

This library can install different loaders, such as Fabric and Paper, for use with the nitro_core library. It is packaged separately so that users who do not want this functionality and only act on the vanilla game don’t have to include them

Note: The functions in this library expect the use of the Tokio runtime and will panic if it is not used

Modules

fabric_quilt
Installation of the Fabric and Quilt modloaders
forge
Installation of NeoForge
paper
Installation of projects from PaperMC, such as the Paper and Folia servers
sponge
Installation of SpongeVanilla